@@ -297,7 +297,7 @@ inline bfloat16 lowest<bfloat16>()
 template <typename T, typename = typename std::enable_if<std::is_arithmetic<T>::value>::type>
 inline bool isfinite(T value)
 {
-    return std::isfinite(value);
+    return std::isfinite(static_cast<double>(value));
 }
 
 inline bool isfinite(half_float::half value)
@@ -314,7 +314,7 @@ inline bool isfinite(bfloat16 value)
 template <typename T, typename = typename std::enable_if<std::is_arithmetic<T>::value>::type>
 inline bool signbit(T value)
 {
-    return std::signbit(value);
+    return std::signbit(static_cast<double>(value));
 }
 
 inline bool signbit(half_float::half value)
