@@ -348,7 +348,7 @@ public:
 
     void do_teardown() override
     {
-        for(auto m : measurements)
+        for(const auto &m : measurements)
         {
             std::cout << m.first << ": " << m.second.count() << "us" << std::endl;
         }
@@ -389,4 +389,4 @@ int main(int argc, char **argv)
 #undef TICK
 #undef TOCK
 #undef TOCK_AVG
-#endif /* ENABLE_EXPERIMENTAL_DYNAMIC_FUSION */
\ No newline at end of file
+#endif /* ENABLE_EXPERIMENTAL_DYNAMIC_FUSION */
